@@ -18,7 +18,8 @@ glue___stsb = Classification(sentence1="sentence1", sentence2="sentence2", label
 super_glue___boolq = Classification(sentence1="question", labels="label")
 super_glue___cb = Classification(sentence1="premise", sentence2="hypothesis", labels="label")
 super_glue___multirc = Classification(
-    cat(["paragraph", "question","answer"], " : "),
+    cat(["paragraph", "question"]),
+    'answer',
     labels='label'
 )
 #super_glue___rte = Classification(sentence1="premise", sentence2="hypothesis", labels="label") # in glue
